@@ -35,6 +35,7 @@ class TamingDecoder(ImageGenerator):
 
         modeling_ckpt_path = os.path.join(modeling_cache_dir, 'last.ckpt')
         if not os.path.exists(modeling_ckpt_path):
+            logging.info("Downloading pre-trained weights for VQ-GAN")
             os.system(
                 f"wget 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1' -O '{modeling_ckpt_path}'"
             )
@@ -42,6 +43,7 @@ class TamingDecoder(ImageGenerator):
         # TODO: update the url with our own config using the correct paths
         modeling_config_path = os.path.join(modeling_cache_dir, 'model.yaml')
         if not os.path.exists(modeling_config_path):
+            logging.info("Downloading `model.yaml` from vipermu taming-transformers fork")
             os.system(
                 f"wget 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml' -O '{modeling_config_path}'"
             )
